@@ -301,7 +301,7 @@ def check_config(
         print(
             'For more information on setting SampleDB configuration, see: '
             'https://scientific-it-systems.iffgit.fz-juelich.de/SampleDB/'
-            'developer_guide/configuration.html',
+            'administrator_guide/configuration.html',
             file=sys.stderr
         )
 
@@ -386,6 +386,9 @@ INVITATION_TIME_LIMIT = 7 * 24 * 60 * 60
 
 # other settings
 ONLY_ADMINS_CAN_MANAGE_LOCATIONS = False
+ONLY_ADMINS_CAN_DELETE_GROUPS = False
+
+LOAD_OBJECTS_IN_BACKGROUND = False
 
 # environment variables override these values
 use_environment_configuration(env_prefix='SAMPLEDB_')
